# Generated by roxygen2: do not edit by hand

export(VietorisRipsComplex)
export(abstract_simplicial_complex)
export(betti_number)
export(boundary)
export(boundary_info)
export(build_vr_filtration)
export(euler_characteristic)
export(extract_persistence_pairs)
export(faces)
export(plot_persistence)
importFrom(Matrix,Matrix)
importFrom(Matrix,rankMatrix)
importFrom(Matrix,sparseMatrix)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_fixed)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(gtools,combinations)
importFrom(igraph,add_edges)
importFrom(igraph,graph.empty)
importFrom(igraph,max_cliques)
importFrom(stats,setNames)
importFrom(utils,combn)
importFrom(utils,tail)
