% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PlotPD.R
\name{plot_landscape}
\alias{plot_landscape}
\title{Plot a Persistence Landscape}
\usage{
plot_landscape(landscape_df)
}
\arguments{
\item{landscape_df}{Data frame from \code{persistence_landscape()}, with
columns \code{t}, \code{k}, \code{value}.}
}
\value{
A ggplot2 object with one line per landscape level
  \eqn{\lambda(k, \cdot)}.
}
\description{
Plot a Persistence Landscape
}
\examples{
points <- matrix(c(0, 1, 1, 0, 0, 0, 1, 1), ncol = 2)
filtration <- build_filtration(points, method = "VR", eps_max = 1.2)
res <- boundary_info(filtration)
pairs <- extract_persistence_pairs(filtration, res$last_1, res$pivot_owner)
landscape <- persistence_landscape(pairs, dimension = 0)
plot_landscape(landscape)
}
